#!/usr/bin/env node

const chalk = require('chalk');
const clear = require('clear');
const figlet = require('figlet');
const fs = require('fs')
const program = require('commander');
const files = require('./lib/files');
const npm = require('./lib/npm');
const inquirer  = require('./lib/inquirer');
const packageJSON = require('./package.json');


program.version(packageJSON.version)
program.usage('[options] <file ...>')
program.option('-v, --version', 'version')
program.parse(process.argv);

clear();

console.log(
  chalk.yellow(
    figlet.textSync('nodock-cli', { horizontalLayout: 'full' })
  )
);

const run = async () => {
  // check that is in a nodock project
  // const path = process.cwd() + '/node_modules/nodock';
  // const found = await files.directoryExists(path);
  // if (!found) {
  //   console.log(chalk.red("Error: make sure you have the nodock module installed via npm in your project directory."));
  //   process.exit(1);
  // }
  // check if new version of nodock
  console.log(chalk.yellow("Alert: checking for update this may take a moment..."));
  const checkUpdate = await npm.checkUpdate();
  if (checkUpdate) {
    const mustUpdate = await inquirer.askOutdated();
    if (mustUpdate.update) {
      const updated = await npm.doUpdate();
      console.log(chalk.green("Success: Package updated."));
      process.exit(1);
    }
  }
  //create docker compose file
  const { data } = await npm.getPath();
  const rootDir = `${data.trim()}/nodock-cli`;

  const questionsImage = await inquirer.askImages(rootDir);
  const exists = files.existsComposeFile();
  if (exists) {
    const questionsOverwrite = await inquirer.askOverwrite();
    if (!questionsOverwrite.overwrite) {
      console.log(chalk.yellow("Alert: did not create docker-compose.yml file."));
      process.exit(1);
    }
  }
  const created = await files.createComposeFile(questionsImage.images, rootDir);
  if (!created) console.log(chalk.red("Error: failed to create docker-compose.yml"));
  console.log(chalk.green("Success: added docker-compose.yml to directory."));
}

run();
